## 1.2.0 / 2018-01-01

* Add `num` word type.
* Add `pick` word type.
* Add lorem_tao  dialect.

## 1.1.1 / 2017-09-22

* Construct plural form for nouns ending on -y

## 1.1.0 / 2017-09-07

* Support count=None for infinite generators

## 1.0.0 / 2017-08-06

* Initial release
